@@ -1,19 +1,16 @@
 """
-Jinja2 template loader for Django 1.2 and above.
+Jinja2 template loader for Django 1.2 and above. Supports Jinja2 extensions,
+and filters written for classic Django templates.
 
-Jinja2loader can load Jinja2 extensions, and filters written for classic Django
-templates.
-
-After installation, add jinja2loader.Loader to your project's settings file,
-e.g:
+After installing, add jinja2loader.Loader to your project's settings file, e.g:
     >>> TEMPLATE_LOADERS = (
     ...     'jinja2loader.Loader',
     ...     'django.template.loaders.filesystem.Loader',
     ...     'django.template.loaders.app_directories.Loader',
     ... )
 
-You probably want to keep the regular Django loaders in there, so you don't
-break apps that have their own templates - such as Django admin.
+You'll probably want to keep the regular Django loaders in there, to not break
+apps that have their own templates - such as Django admin.
 
 
 Settings:
@@ -32,30 +29,15 @@ Settings:
     
     JINJA2_USE_DEFAULT_DJANGOFILTERS:
         If True (default), loads Django's built-in filters.
+
+
+This work is licenced under the Creative Commons Public Domain License. To view
+a copy of this licence, visit http://creativecommons.org/licenses/publicdomain/
+or send a letter to Creative Commons, 171 Second Street, Suite 300,
+San Francisco, California 94105, USA.
 """
 
 
-# Copyright (C) 2010 Nathan Reynolds
-# 
-# This software is provided 'as-is', without any express or implied
-# warranty.  In no event will the authors be held liable for any damages
-# arising from the use of this software.
-# 
-# Permission is granted to anyone to use this software for any purpose,
-# including commercial applications, and to alter it and redistribute it
-# freely, subject to the following restrictions:
-# 
-# 1. The origin of this software must not be misrepresented; you must not
-#    claim that you wrote the original software. If you use this software
-#    in a product, an acknowledgment in the product documentation would be
-#    appreciated but is not required.
-# 2. Altered source versions must be plainly marked as such, and must not be
-#    misrepresented as being the original software.
-# 3. This notice may not be removed or altered from any source distribution.
-# 
-# Nathan Reynolds nath@nreynolds.co.uk
-
-
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.template import loader, TemplateDoesNotExist, InvalidTemplateLibrary
@@ -83,7 +65,7 @@ def load_django_filters(filters, library_names, use_default_filters):
         if not library:
             raise InvalidTemplateLibrary('Couldn\'t load django.template.defaultfilters')
         
-        # Update the filters dict for filters that don't already exist, i.e
+        # Update the dict for filters that don't already exist, i.e
         # jinja2's built-in filters.
         filters.update(dict(
             (name, value)
